==> pangea-center-api-0.0.28-sources.jar: cn/com/duiba/tuia/pangea/center/api/remoteservice/RemoteAppSlotFlowService.java <==
package cn.com.duiba.tuia.pangea.center.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.pangea.center.api.dto.PageResultDto;
import cn.com.duiba.tuia.pangea.center.api.req.flowmanager.ReqFlowBaseByPageDto;
import cn.com.duiba.tuia.pangea.center.api.req.flowmanager.ReqShieldFlowDto;
import cn.com.duiba.tuia.pangea.center.api.req.flowmanager.ReqUpdateRatioDto;
import cn.com.duiba.tuia.pangea.center.api.req.flowmanager.ReqUpdateStatusDto;
import cn.com.duiba.tuia.pangea.center.api.req.flowmanager.ReqWholeOrSlotRatioDto;
import cn.com.duiba.tuia.pangea.center.api.req.openweb.PgPlanSlotRatioReq;
import cn.com.duiba.tuia.pangea.center.api.rsp.flowmanager.RspFlowBaseDto;
import cn.com.duiba.tuia.pangea.center.api.rsp.flowmanager.RspShieldFlowDto;
import cn.com.duiba.tuia.pangea.center.api.rsp.flowmanager.RspWholeOrSlotRatioDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.List;

/**
 * @author yuantong
 * @version 1.0
 * @since 2019-09-08 10:25
 */
@AdvancedFeignClient
public interface RemoteAppSlotFlowService {


    /**
     * 查询 可测试流量
     * @param dto
     * @return
     */
    PageResultDto<RspFlowBaseDto> selectTestSlotListPage(ReqFlowBaseByPageDto dto);

    /**
     * 查询 黑名单测试流量
     * @param dto
     * @return
     */
    PageResultDto<RspShieldFlowDto> selectShieldSlotListPage(ReqShieldFlowDto dto);


    /**
     * 查询 大盘占比 切流量
     * @param dto
     * @return
     */
    RspWholeOrSlotRatioDto selectTestWholeSlotRatio(ReqWholeOrSlotRatioDto dto);

    /**
     * 查询媒体广告位 切流量占比
     * @param dto
     * @return
     */
    RspWholeOrSlotRatioDto selectTestSomeSlotRatio(ReqWholeOrSlotRatioDto dto);

    /**
     * 更新流量占比
     * @param dto
     * @return
     */
    DubboResult<Integer> updateRatio(ReqUpdateRatioDto dto);

    /**
     * 更新black_deleted状态
     * @param reqUpdateStatusDto
     * @return
     */
    Integer addOrUpdateStatus(ReqUpdateStatusDto reqUpdateStatusDto);

    /**
     * 单个更新移除 TestAppSlot 名单
     * @param reqUpdateStatusDto
     * @return
     */
    Integer removeTestAppSlotShield(ReqUpdateStatusDto reqUpdateStatusDto);


    /**
     * 获取某个测试计划的比例
     * @param ratioReq
     * @return
     */
    Integer getRatioBySlotIdAndActivityId(PgPlanSlotRatioReq ratioReq);

    /**
     * 批量上传 cvs 黑名单
     * @param reqUpdateStatusDto
     * @return
     */
    Integer uploadBatchShieldList(ReqUpdateStatusDto reqUpdateStatusDto);


    /**
     * 处理媒体管理平台的发过来的rpc 广告位处理
     * @param slotIds
     * @return
     */
    void dealBatchShieldList(List<Long> slotIds);

}

==> pangea-center-api-0.0.35-20200925.084243-5-sources.jar: cn/com/duiba/tuia/pangea/center/api/remoteservice/RemoteAppSlotFlowService.java <==
package cn.com.duiba.tuia.pangea.center.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.pangea.center.api.dto.PageResultDto;
import cn.com.duiba.tuia.pangea.center.api.req.flowmanager.ReqFlowBaseByPageDto;
import cn.com.duiba.tuia.pangea.center.api.req.flowmanager.ReqShieldFlowDto;
import cn.com.duiba.tuia.pangea.center.api.req.flowmanager.ReqUpdateRatioDto;
import cn.com.duiba.tuia.pangea.center.api.req.flowmanager.ReqUpdateStatusDto;
import cn.com.duiba.tuia.pangea.center.api.req.flowmanager.ReqWholeOrSlotRatioDto;
import cn.com.duiba.tuia.pangea.center.api.req.openweb.PgPlanSlotRatioReq;
import cn.com.duiba.tuia.pangea.center.api.rsp.flowmanager.RspFlowBaseDto;
import cn.com.duiba.tuia.pangea.center.api.rsp.flowmanager.RspShieldFlowDto;
import cn.com.duiba.tuia.pangea.center.api.rsp.flowmanager.RspWholeOrSlotRatioDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.List;

/**
 * @author yuantong
 * @version 1.0
 * @since 2019-09-08 10:25
 */
@AdvancedFeignClient
public interface RemoteAppSlotFlowService {


    /**
     * 查询 可测试流量
     * @param dto
     * @return
     */
    PageResultDto<RspFlowBaseDto> selectTestSlotListPage(ReqFlowBaseByPageDto dto);

    /**
     * 查询 黑名单测试流量
     * @param dto
     * @return
     */
    PageResultDto<RspShieldFlowDto> selectShieldSlotListPage(ReqShieldFlowDto dto);


    /**
     * 查询 大盘占比 切流量
     * @param dto
     * @return
     */
    RspWholeOrSlotRatioDto selectTestWholeSlotRatio(ReqWholeOrSlotRatioDto dto);

    /**
     * 查询媒体广告位 切流量占比
     * @param dto
     * @return
     */
    RspWholeOrSlotRatioDto selectTestSomeSlotRatio(ReqWholeOrSlotRatioDto dto);

    /**
     * 更新流量占比
     * @param dto
     * @return
     */
    DubboResult<Integer> updateRatio(ReqUpdateRatioDto dto);

    /**
     * 更新black_deleted状态
     * @param reqUpdateStatusDto
     * @return
     */
    Integer addOrUpdateStatus(ReqUpdateStatusDto reqUpdateStatusDto);

    /**
     * 单个更新移除 TestAppSlot 名单
     * @param reqUpdateStatusDto
     * @return
     */
    Integer removeTestAppSlotShield(ReqUpdateStatusDto reqUpdateStatusDto);


    /**
     * 获取某个测试计划的比例
     * @param ratioReq
     * @return
     */
    Integer getRatioBySlotIdAndActivityId(PgPlanSlotRatioReq ratioReq);

    /**
     * 批量上传 cvs 黑名单
     * @param reqUpdateStatusDto
     * @return
     */
    Integer uploadBatchShieldList(ReqUpdateStatusDto reqUpdateStatusDto);


    /**
     * 处理媒体管理平台的发过来的rpc 广告位处理
     * @param slotIds
     * @return
     */
    void dealBatchShieldList(List<Long> slotIds);

    /**
     * 根据appIds更新对应的 广告位黑名单添加方式，0：广告位ID，1：媒体ID
     * @param addType 广告位黑名单添加方式，0：广告位ID，1：媒体ID
     * @param appIds
     * @return
     */
    boolean updateAddTypeByAppIds(Integer addType, List<Long> appIds);
}
